package cz.moneta.test.regression.commercial.auto.smartauto;

import cz.moneta.test.harness.annotations.JiraTestCase;
import cz.moneta.test.harness.annotations.TestCase;
import cz.moneta.test.harness.annotations.TestScenario;
import cz.moneta.test.regression.commercial.auto.smartauto.mockdata.CaravanMock;
import org.junit.jupiter.api.Disabled;

@Disabled
@TestScenario(name = "Successful filled new calculation for caravan.")
public class CalculationCaravanTest extends AbstractTest {
    @JiraTestCase(id = "LAMD-T970")
    @TestCase(name = "Commodity: caravan, Customer: consumer, State: new, Type: M1, Product: autoCREDIT," +
            "Product Type: Standard, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCaravan1() {
        sharedTasks(CaravanMock.prepareCalculationCaravan1());
    }

    @JiraTestCase(id = "LAMD-T971")
    @TestCase(name = "Commodity: caravan, Customer: consumer, State: new, Type: M1, Product: autoCREDIT," +
            "Product Type: Standard, VAT: yes, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCaravan1_1() {
        sharedTasks(CaravanMock.prepareCalculationCaravan1_1());
    }

    @JiraTestCase(id = "LAMD-T972")
    @TestCase(name = "Commodity: caravan, Customer: consumer, State: new, Type: M1, Product: autoCREDIT," +
            "Product Type: C2C, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCaravan2() {
        sharedTasks(CaravanMock.prepareCalculationCaravan2());
    }

    @JiraTestCase(id = "LAMD-T973")
    @TestCase(name = "Commodity: caravan, Customer: consumer, State: used, Type: M1, Product: autoCREDIT," +
            "Product Type: Standard, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCaravan4() {
        sharedTasks(CaravanMock.prepareCalculationCaravan4());
    }

    @JiraTestCase(id = "LAMD-T974")
    @TestCase(name = "Commodity: caravan, Customer: consumer, State: used, Type: M1, Product: autoCREDIT," +
            "Product Type: C2C, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCaravan5() {
        sharedTasks(CaravanMock.prepareCalculationCaravan5());
    }

    @JiraTestCase(id = "LAMD-T975")
    @TestCase(name = "Commodity: caravan, Customer: businessman without vat, State: new, Type: M1, Product: autoCREDIT," +
            "Product Type: Standard, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCaravan7() {
        sharedTasks(CaravanMock.prepareCalculationCaravan7());
    }

    @JiraTestCase(id = "LAMD-T976")
    @TestCase(name = "Commodity: caravan, Customer: businessman without vat, State: new, Type: M1, Product: autoCREDIT," +
            "Product Type: C2C, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCaravan8() {
        sharedTasks(CaravanMock.prepareCalculationCaravan8());
    }

    @JiraTestCase(id = "LAMD-T977")
    @TestCase(name = "Commodity: caravan, Customer: businessman without vat, State: new, Type: M1, Product: autoCREDIT," +
            "Product Type: Back loan, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCaravan9() {
        sharedTasks(CaravanMock.prepareCalculationCaravan9());
    }

    @JiraTestCase(id = "LAMD-T978")
    @TestCase(name = "Commodity: caravan, Customer: businessman without vat, State: used, Type: M1, Product: autoCREDIT," +
            "Product Type: Standard, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCaravan10() {
        sharedTasks(CaravanMock.prepareCalculationCaravan10());
    }

    @JiraTestCase(id = "LAMD-T979")
    @TestCase(name = "Commodity: caravan, Customer: businessman without vat, State: used, Type: M1, Product: autoCREDIT," +
            "Product Type: C2C, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCaravan11() {
        sharedTasks(CaravanMock.prepareCalculationCaravan11());
    }

    @JiraTestCase(id = "LAMD-T980")
    @TestCase(name = "Commodity: caravan, Customer: businessman without vat, State: used, Type: M1, Product: autoCREDIT," +
            "Product Type: Back loan, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCaravan12() {
        sharedTasks(CaravanMock.prepareCalculationCaravan12());
    }
}
